/*
 * Project name:
     SPI_Lcd_COG_2x16 (Simple demonstration of the SPI Lcd 4-bit Library functions)
 * Copyright:
     (c) Mikroelektronika, 2012.
 * Revision History:
     20080930:
       - initial release;
     20090720
       - modified by Slavisa Zlatanovic;
     20120522:
       - modified for PIC18F25K22 (FJ);
 * Description:
     This is a simple demonstration of SPI Lcd 4-bit library functions.
     SPI Lcd Library sends commands to Port Expander and it controls
     Port Expander's output PORTB (connected to Serial LCD).
 * Test configuration:
     MCU:             PIC18F25K22
                      http://ww1.microchip.com/downloads/en/DeviceDoc/41412D.pdf
     Dev.Board:       Ready for PIC Board - DIP28
                      http://www.mikroe.com/eng/products/view/963/ready-for-pic-dip28/
     Oscillator:      HS-PLL 32.0000 MHz, 8.0000 MHz Crystal
     Ext. Modules:    COG 2x16 LCD Board - ac:COG_2x16
                      http://www.mikroe.com/eng/products/view/363/cog-2x16-lcd-board/
                      Port Expander Board - ac:Port_Expander_Board
                      http://www.mikroe.com/eng/products/view/142/port-expander-board/
     SW:              mikroC PRO for PIC
                      http://www.mikroe.com/eng/products/view/7/mikroc-pro-for-pic/
 * NOTES:
     - None.
 */

char *text = "www.mikroe.com";

// Port Expander module connections
sbit  SPExpanderRST at LATC0_bit;
sbit  SPExpanderCS  at LATC1_bit;
sbit  SPExpanderRST_Direction at TRISC0_bit;
sbit  SPExpanderCS_Direction  at TRISC1_bit;
// End Port Expander module connections

char i;                                     // Loop variable

void Move_Delay() {                         // Function used for text moving
  Delay_ms(500);                            // You can change the moving speed here
}

void main() {

  ANSELC  = 0;                              // Configure pins as digital

  C1ON_bit = 0;                             // Disable comparators
  C2ON_bit = 0;

  // Port Expander Library uses SPI1 module
  SPI1_Init();                              // Initialize SPI module used with PortExpander

  SPI_Lcd_Config(0);                        // Initialize Lcd over SPI interface
  SPI_Lcd_Cmd(_LCD_CLEAR);                  // Clear display
  SPI_Lcd_Cmd(_LCD_CURSOR_OFF);             // Turn cursor off
  SPI_Lcd_Out(1,1, "mikroElektronika");     // Print text to Lcd, 1st row, 1st column
  SPI_Lcd_Out(2,2, text);                   // Print text to Lcd, 2nd row, 2nd column

  Delay_1sec();
  Delay_1sec();

// Moving text
  for(i=0; i<4; i++) {                      // Move text to the right 4 times
    SPI_Lcd_Cmd(_LCD_SHIFT_RIGHT);
    Move_Delay();
  }

  while(1) {                                // Endless loop
    for(i=0; i<8; i++) {                    // Move text to the left 7 times
      SPI_Lcd_Cmd(_LCD_SHIFT_LEFT);
      Move_Delay();
    }

    for(i=0; i<8; i++) {                    // Move text to the right 7 times
      SPI_Lcd_Cmd(_LCD_SHIFT_RIGHT);
      Move_Delay();
    }
  }
}